==> fast_qr-0.2.1.crate: fast_qr-0.2.1/svg_convert.py <==
a = [
    [
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        True,
        True,
        False,
        False,
        False,
        True,
        False,
        True,
        False,
        False,
        True,
        False,
        True,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
    ],
    [
        True,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        True,
        True,
        True,
        False,
        False,
        True,
        False,
        True,
        False,
        False,
        True,
        True,
        False,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        True,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        True,
        False,
        False,
        False,
        True,
        True,
        False,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
        True,
        False,
        True,
        False,
        False,
        True,
        False,
        False,
        True,
        False,
        True,
        False,
        False,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        True,
        True,
        True,
        True,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
    ],
    [
        True,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        True,
        True,
        True,
        True,
        True,
        False,
        False,
        True,
        False,
        False,
        True,
        False,
        False,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        True,
    ],
    [
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
    ],
    [
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        True,
        True,
        False,
        True,
        True,
        True,
        True,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        False,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        False,
        True,
        True,
        True,
    ],
    [
        False,
        False,
        False,
        False,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        False,
        False,
        False,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        True,
    ],
    [
        True,
        False,
        True,
        True,
        False,
        True,
        True,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        True,
        True,
        True,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        True,
        False,
        True,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        True,
        True,
        False,
        True,
        False,
        True,
        True,
        True,
        False,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        False,
    ],
    [
        False,
        True,
        False,
        True,
        False,
        True,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        True,
        True,
        False,
        True,
        False,
        False,
        True,
        True,
        True,
    ],
    [
        False,
        True,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        False,
        True,
        True,
        True,
        True,
        False,
        True,
        True,
        False,
        True,
        True,
    ],
    [
        True,
        True,
        False,
        True,
        False,
        True,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
        True,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        True,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        True,
        False,
        False,
        True,
        False,
        False,
        False,
        False,
        True,
        True,
        False,
        True,
        False,
        False,
        False,
        True,
        True,
        False,
        True,
        False,
    ],
    [
        False,
        True,
        True,
        False,
        True,
        True,
        True,
        False,
        False,
        True,
        True,
        False,
        True,
        False,
        False,
        True,
        True,
        False,
        False,
        False,
        False,
        True,
        False,
        False,
        False,
        True,
        True,
        True,
        False,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        True,
        False,
        True,
        True,
        False,
        False,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        True,
        True,
    ],
    [
        True,
        False,
        False,
        True,
        True,
        False,
        True,
        False,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
        True,
        True,
        False,
        True,
        False,
        False,
        False,
    ],
    [
        True,
        False,
        True,
        False,
        False,
        True,
        True,
        True,
        False,
        True,
        True,
        True,
        True,
        False,
        False,
        True,
        True,
        True,
        False,
        True,
        True,
        False,
        True,
        False,
        True,
        False,
        False,
        True,
        False,
    ],
    [
        True,
        False,
        True,
        True,
        False,
        True,
        True,
        False,
        True,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
    ],
    [
        False,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        True,
        False,
        False,
        False,
        True,
        False,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
        False,
        True,
        True,
        False,
        False,
        True,
    ],
    [
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        False,
        False,
        True,
        False,
        True,
        True,
        True,
        True,
        False,
        True,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        False,
        False,
        False,
        False,
    ],
    [
        True,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        False,
        True,
        True,
        True,
        True,
        True,
        False,
        True,
        True,
        False,
        True,
        True,
        True,
        False,
        False,
        False,
        True,
        True,
        False,
        False,
        False,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        True,
        False,
        False,
        True,
        False,
        False,
        False,
        True,
        True,
        True,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        True,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        True,
        False,
        True,
        True,
        True,
        True,
        False,
        False,
        False,
        True,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        True,
        False,
        False,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        True,
        True,
        False,
    ],
    [
        True,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        False,
        True,
        False,
        False,
        False,
        False,
        True,
        True,
        True,
        True,
        False,
        False,
        False,
        False,
        True,
        False,
        True,
        True,
        False,
        True,
        False,
    ],
    [
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        False,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        False,
        True,
        False,
        False,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        False,
    ],
]

pos = []
for i, line in enumerate(a):
    for j, cell in enumerate(line):
        if cell:
            pos.append((i, j))

path = "".join(map(lambda e: f"M{e[1] + 4},{e[0] + 4}h1v1h-1", pos))

svgContent = f"""<svg viewBox='0 0 {29 + 8} {29 + 8}' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
  <path d='{path}' />
</svg>"""

print(svgContent)

==> fast_qr-0.3.1.crate: fast_qr-0.3.1/svg_convert.py <==
a = [
    [
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
    ],
    [
        True,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        True,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
    ],
    [
        True,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        True,
    ],
    [
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        True,
        True,
        True,
        True,
        True,
        True,
        True,
    ],
    [
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        False,
        False,
        True,
        False,
        False,
        False,
        True,
        True,
        True,
        False,
        False,
        True,
        False,
        False,
        True,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        False,
        False,
        True,
        False,
        False,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        False,
        False,
        True,
        False,
        False,
        False,
        True,
        False,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        False,
        False,
        True,
        False,
        False,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        False,
        False,
        True,
        True,
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        True,
        False,
        True,
        True,
        False,
        False,
        True,
        False,
        True,
        False,
        True,
        False,
        False,
    ],
    [
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        True,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        True,
        False,
        True,
        True,
        True,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        True,
        False,
        False,
        False,
        False,
        False,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
    [
        True,
        True,
        True,
        True,
        True,
        True,
        True,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
        False,
    ],
]

pos = []
for i, line in enumerate(a):
    for j, cell in enumerate(line):
        if cell:
            pos.append((i, j))

# path = "".join(map(lambda e: f"M{e[1] + 4},{e[0] + 4}h1v1h-1", pos))
#
# svgContent = f"""<svg viewBox='0 0 {29 + 8} {29 + 8}' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
#   <path d='{path}' />
# </svg>"""


import sys
import numpy as np

np.random.seed(0)
np.random.shuffle(pos)

path = "\n".join(
    map(
        lambda e: f"<path class=\"default_qr\" style='--d:{round(e[0] / (10 + e[0]/10), 2)}s' d='M{e[1][1] + 4},{e[1][0] + 4}h1v1h-1' />",
        enumerate(pos),
    )
)


print(
    f"""<svg viewBox='0 0 {29 + 8} {29 + 8}' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
{path}
"""
)

if not "--anim" in sys.argv:
    print("</svg>")
    exit()

print(
    f"""
<style>
  .default_qr {{
    --d: 0s;
    fill: transparent;
    animation-fill-mode: forwards;
    animation-name: render;
    animation-duration: 2s;
    animation-delay: var(--d);
  }}

  @keyframes render {{
    from {{
      fill: #f5f5f500;
    }}
    to {{
      fill: #f5f5f5;
    }}
  }}
</style>
</svg>
"""
)
